@@ -11,6 +11,8 @@ pub struct Configuration {
     #[serde(rename = "commentLine.forceSpaceAfterSlashes")]
     pub comment_line_force_space_after_slashes: bool,
     pub ignore_node_comment_text: String,
+    #[serde(rename = "array.preferSingleLine")]
     pub array_prefer_single_line: bool,
+    #[serde(rename = "object.preferSingleLine")]
     pub object_prefer_single_line: bool,
 }
